

# Visualizar resultados ---------------------------------------------------


# Cores para gráfico
colors <- c(
  "#282f6b", # blue
  "#b22200", # red
  "#eace3f", # yellow
  "#224f20", # green
  "black",
  "#5f487c", # purple
  "#b35c1e", # orange
  "#419391", # turquoise
  "#839c56", # light green
  "#3b89bc", # light blue
  "#666666"  # gray
  )


# Última data de observação
obs_max_date <- max(lubridate::as_date(dataset_idp$date))


# Gráfico da previsão out-of-sample (fanchart)
plt_previsao <- fanchart_tbl %>%
  ggplot2::ggplot(ggplot2::aes(x = `date`)) +
  ggplot2::geom_ribbon(
    ggplot2::aes(ymin = `80%_lower`, ymax = `80%_upper`),
    fill  = colors[1],
    alpha = 0.5,
    data  = dplyr::filter(fanchart_tbl, date >= obs_max_date)
    ) +
  ggplot2::geom_ribbon(
    ggplot2::aes(ymin = `95%_lower`, ymax = `95%_upper`),
    fill  = colors[1],
    alpha = 0.5,
    data  = dplyr::filter(fanchart_tbl, date >= obs_max_date)
    ) +
  ggplot2::geom_line(
    ggplot2::aes(y = `value`),
    size  = 2,
    color = colors[5],
    data  = dplyr::filter(fanchart_tbl, date <= obs_max_date) %>%
      dplyr::slice_tail(n = 72)
    ) +
  ggplot2::geom_line(
    ggplot2::aes(y = `value`),
    size  = 2,
    color = colors[1],
    data  = dplyr::filter(fanchart_tbl, date >= obs_max_date)
    ) +
  ggplot2::geom_vline(xintercept = obs_max_date, linetype = "dashed") +
  ggplot2::scale_y_continuous(
    breaks = scales::breaks_pretty(),
    labels = scales::label_dollar(big.mark = ".", decimal.mark = ",")
    ) +
  ggplot2::scale_x_date(
    breaks = scales::breaks_width("5 months"),
    labels = function(x) dplyr::if_else(
      is.na(dplyr::lag(x)) | !lubridate::year(dplyr::lag(x)) == lubridate::year(x),
      paste(lubridate::month(x, label = TRUE), "\n", lubridate::year(x)),
      paste(lubridate::month(x, label = TRUE))
      )
    ) +
  ggplot2::labs(
    title    = "**Fanchart**: Previs\u00e3o do IDP",
    subtitle = "Investimento Direto no Pa\u00eds, acumulado em 12 meses<br>Intervalos de confian\u00e7a de 80% e 95%",
    y        = "US$ (milh\u00f5es)",
    x        = NULL,
    caption  = "**Dados:** BCB e Secex | **Elabora\u00e7\u00e3o:** analisemacro.com.br"
    ) +
  ggplot2::theme_light() +
  ggplot2::theme(
    plot.title       = ggtext::element_markdown(size = 25, colour = colors[1]),
    axis.text        = ggtext::element_markdown(size = 12, face = "bold"),
    axis.title       = ggtext::element_markdown(size = 12, face = "bold"),
    panel.grid.minor = ggplot2::element_blank(),
    plot.subtitle    = ggtext::element_markdown(size = 16),
    plot.caption     = ggtext::element_textbox_simple(
      size   = 12,
      colour = "grey20",
      margin = ggplot2::margin(10, 5.5, 10, 5.5)
      )
    )


# Juntar dados de acurácia
acc_rmse <- rmse_baseline %>%
  dplyr::bind_rows(rmse_focus) %>%
  dplyr::mutate(
    .model = dplyr::recode(
      .model,
      "rw"           = "Random Walk",
      "rw_drift"     = "Random Walk com drift",
      "arima"        = "Auto ARIMA",
      "arima_manual" = "ARIMA manual",
      "arima_xreg"   = "ARIMAX",
      "ets"          = "Suaviza\u00e7\u00e3o Exponencial (ETS)",
      "ols"          = "MQO",
      "focus"        = "Focus"
    )
  ) %>%
  dplyr::arrange(h, rmse, .model) %>%
  dplyr::select("Horizonte" = "h", "Modelo" = ".model", "RMSE" = "rmse")


# Gráfico do RMSE por horizonte de previsão vs. modelo
plt_rmse <- acc_rmse %>%
  ggplot2::ggplot(
    ggplot2::aes(x = `Horizonte`, y = `RMSE`, colour = `Modelo`)
  ) +
  ggplot2::geom_line(size = 1.5) +
  ggplot2::geom_point(size = 3) +
  ggplot2::scale_colour_manual(NULL, values = colors) +
  ggplot2::scale_y_continuous(
    breaks = scales::breaks_pretty(),
    labels = scales::number_format(accuracy = 1, decimal.mark = ",", big.mark = ".")
  ) +
  ggplot2::scale_x_continuous(
    labels = scales::number_format(accuracy = 1),
    breaks = 1:24
  ) +
  ggplot2::theme_light() +
  ggplot2::labs(
    title    = "**Acur\u00e1cia**: ARIMAX vs. Benchmarks",
    subtitle = "Modelo de previs\u00e3o do IDP",
    x        = "Horizonte (meses)",
    caption  = "**Dados:** BCB e Secex | **Elabora\u00e7\u00e3o:** analisemacro.com.br"
  ) +
  ggplot2::theme(
    plot.title       = ggtext::element_markdown(size = 25, colour = colors[1]),
    axis.text        = ggtext::element_markdown(size = 12, face = "bold"),
    axis.title       = ggtext::element_markdown(size = 12, face = "bold"),
    panel.grid.minor = ggplot2::element_blank(),
    legend.position  = "bottom",
    legend.key.width = ggplot2::unit(1, "cm"),
    plot.subtitle    = ggtext::element_markdown(size = 16),
    plot.caption     = ggtext::element_textbox_simple(
      size   = 12,
      colour = "grey20",
      margin = ggplot2::margin(10, 5.5, 10, 5.5)
    )
  )


# Tabela de pontos de previsão
tbl_previsao <- fanchart_tbl %>%
  dplyr::filter(date > obs_max_date) %>%
  dplyr::mutate(`date` = lubridate::as_date(.data$`date`) %>% format("%b/%Y")) %>%
  dplyr::relocate(
    "M\u00eas" = "date", "LI 95%" = "95%_lower", "LI 80%" = "80%_lower",
    "Previs\u00e3o" = "value", "LS 80%" = "80%_upper", "LS 95%" = "95%_upper"
  ) %>%
  DT::datatable(
    options = list(dom = "tip", pageLength = 4, scrollX = TRUE, scrollY = TRUE),
    rownames = FALSE,
    caption = htmltools::tags$caption(
      style = 'caption-side: bottom; text-align: left;',
      "LI = Limite inferior, LS = Limite superior"
    )
  ) %>%
  DT::formatCurrency(columns = 2:6, digits = 2, dec.mark = ",", mark = ".", currency = "$") %>%
  DT::formatStyle(columns = 4, fontWeight = "bold")


# Tabela com valores do RMSE vs. horizonte/modelos
tbl_rmse <- acc_rmse %>%
  DT::datatable(
    rownames = FALSE,
    options = list(dom = "tip", pageLength = 5, scrollX = TRUE, scrollY = TRUE)
  ) %>%
  DT::formatRound(columns = 3, digits = 2, dec.mark = ",", mark = ".")

