
# Cenários ----------------------------------------------------------------


# Horizonte de previsão/cenários
horizon <- 24

# Fórmula para estimação do modelo multivariado
vars_form <- as.formula( # especificação de fórmula dos modelos
  paste(
    "idp ~",    # variável dependente
    paste0(     # variáveis independentes
      names(dataset_idp)[!names(dataset_idp) %in% c("date", "idp")],
      collapse = " + "
      )
    )
  )

# Criar cenários para variáveis independentes, por conveniência serão
# utilizados modelos univariados através de um auto ARIMA
xreg_scenarios <- purrr::map_df(
  .x = dataset_idp[all.vars(vars_form)[-1]],
  .f = ~{
    forecast::auto.arima(.x) %>%
      forecast::forecast(h = horizon) %>%
      magrittr::extract2("mean") %>%
      as.numeric()
      }
    ) %>%
  dplyr::mutate(
    date = seq.Date(
      from       = lubridate::as_date(max(dataset_idp$date) + 1),
      by         = "month",
      length.out = horizon
      ) %>%
      tsibble::yearmonth()
    ) %>%
  tsibble::as_tsibble(index = "date")



# Estimar modelo ----------------------------------------------------------


# Estimar
fit_arima_xreg <- df_pca %>%
  dplyr::mutate(date = tsibble::yearmonth(.data$date)) %>%
  tsibble::as_tsibble(index = "date") %>%
  fabletools::model(
    arima_xreg = fable::ARIMA(vars_form)
    )


# Previsão ----------------------------------------------------------------


# Previsão fora da amostra
oos_fcst <- fit_arima_xreg %>%
  fabletools::forecast(new_data = xreg_scenarios)


# Extrair pontos de previsão e intervalos de confiança
fanchart_tbl <- oos_fcst %>%
  fabletools::hilo() %>%
  fabletools::unpack_hilo(c("80%", "95%")) %>%
  dplyr::as_tibble() %>%
  dplyr::select("date", "value" = ".mean", dplyr::contains("%")) %>%
  dplyr::mutate(date = lubridate::as_date(.data$date)) %>%
  dplyr::bind_rows(df_pca %>% dplyr::select("date", "value" = "idp")) %>%
  dplyr::arrange(.data$date) %>%
  dplyr::mutate(
    dplyr::across(
      dplyr::contains("%"),
      ~dplyr::coalesce(.x, value)
    )
  )

