
# Modelos baseline --------------------------------------------------------

# Configurações e objetos auxiliares
horizon <- 24   # horizonte de previsão máximo
init_obs <- 120 # número de observações iniciais na estratégia recursiva
vars_form <- as.formula( # especificação de fórmula dos modelos
  paste(
    "idp ~",    # variável dependente
    paste0(     # variáveis independentes
      names(dataset_idp)[!names(dataset_idp) %in% c("date", "idp")],
      collapse = " + "
    )
  )
)

# Criar configuração de Validação Cruzada (CV)
dataset_cv_baseline <- dataset_idp %>%
  tsibble::stretch_tsibble(
    .step = 1,       # acréscimo sucessivo de observações da amostra
    .init = init_obs # tamanho da janela amostral inicial
  )

# Criar amostra de teste de validação cruzada
dataset_test_baseline <- tsibble::new_data(dataset_cv_baseline, n = horizon) %>%
  dplyr::left_join(dataset_idp, by = "date")

# Estimar modelos
#future::plan(future::multisession)         # define processamento paralelo
fit_baseline <- dataset_cv_baseline %>%
  fabletools::model(                        # estimar modelos com fable
    rw              = fable::RW(idp),
    rw_drift        = fable::RW(idp ~ drift()),
    arima           = fable::ARIMA(idp),
    arima_manual    = fable::ARIMA(idp ~ pdq(p = c(1, 2, 12), d = 0:2, q = c(1, 2, 5, 12, 21))),
    arima_xreg      = fable::ARIMA(vars_form),
    ets             = fable::ETS(idp),
    ols             = fable::TSLM(vars_form)
    )

# Previsão na amostra de teste (usando subamostras de CV)
frcst_baseline <- fit_baseline %>%
  fabletools::forecast(new_data = dataset_test_baseline) %>%
  dplyr::group_by(.id, .model) %>%
  dplyr::mutate(h = dplyr::row_number()) %>%
  dplyr::ungroup()

# Salvar ajustes dos modelos e previsões
# readr::write_rds(fit_baseline, "data/fit_baseline.rds")
# readr::write_rds(frcst_baseline, "data/frcst_baseline.rds")
