#' Report number of differences to make time series stationary (vectorized)
#'
#' @param x List-like object with vectors of the series to be tested
#' @param na_rm Remove NAs from x?
#'
#' @return Tibble with variable name from x and the number of differences found
#' @export
report_ndiffs <- function(x, na_rm = TRUE){

  ndiffs_tests <- list(kpss = "kpss", pp = "pp", adf = "adf")

  purrr::map(
    .x = if(na_rm){na.omit(x)} else x,
    .f = ~purrr::map(
      ndiffs_tests,
      function(y){forecast::ndiffs(.x, alpha = 0.05, y)}
    )
  ) %>%
    purrr::map_df(dplyr::bind_rows, .id = "variable") %>%
    dplyr::mutate(
      ndiffs = purrr::pmap_dbl(
        .l = list(kpss, adf, pp),
        .f = ~{ sort(table(c(..1, ..2, ..3)), decreasing = TRUE)[1] %>%
            names() %>%
            as.integer()
        }
      )
    )

}


